(* :Name: CCDPhotometry`Photometry` *)

(* :Title: Various tools for use in the
     reduction of astronomical CCD FITS images *)

(* :Author: Jeff Bryant *)

(* :Context: CCDPhotometry`Photometry` *)

(* :Package Version: 1.0 *)

(* :History:
       Originally written by Jeff Bryant in April 2003.
*)

(* :Keywords:	*)

(* :Source:	*)

(* :Summary:
This package contains various tools for performing differential aperture 
	photometry on CCD FITS images
*)

(* :Mathematica Version: 5.0 *)

(*****************************************************************************)


BeginPackage["CCDPhotometry`Photometry`", "CCDPhotometry`Dates`", "CCDPhotometry`Headers`", "CCDPhotometry`ImageLoad`"]

IsolateRegion::usage =
"IsolateRegion[imgobj_List, {i_Integer, j_Integer}, r_Integer] returns a submatrix of the supplied FITS
image object that is centered at {i, j} and has width and height, r."

Photometry::usage =
"Photometry[imgobj_List, {r_, c_}, rad_Integer] sums up all of the pixel values in the 
specified FITS image object that are centered at {r, c} and that lie within an aperture with radius, rad."

Phase::usage =  
"Phase[imgobj_List, knownmin_Real, orbper_Real] returns the orbital phase of an object based on information
in the header of the FITS image object.  The HJD of a known minimum and the orbital period in days are also 
required."


Begin["`Private`"]

IsolateRegion[imgobj_FitsObject, {i_Integer, j_Integer}, r_Integer] := 
	Take[imgobj[[1, 1, 2]], {i - r, i + r}, {j - r, j + r}];


Photometry[imgobj_FitsObject, {r_, c_}, rad_Integer]:=
	Module[{tmp},
	tmp = Join @@ Table[
            Take[imgobj[[1, 1, 2]], {r + i}, 
              c + {-1, 1} * Floor[Sqrt[(rad^2 - i^2)]]], {i, -rad, rad}]; 
	Plus @@ Flatten[tmp]];


Phase[imgobj_FitsObject, knownmin_Real, orbper_Real] := Module[{tmp},
	tmp = ((HeliocentricJulianDate[ImageTime[imgobj], ImageRA[imgobj], 
	  ImageDEC[imgobj]] + 2400000) - knownmin)/orbper;
	FractionalPart[tmp]]; 

	 
(*========================================================================*)


 End[ ] (* "CCDPhotometry`Headers`Photometry` *)

 EndPackage[ ] (* "CCDPhotometry`Photometry`" *)
