(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6208,        209]*)
(*NotebookOutlinePosition[      8236,        270]*)
(*  CellTagsIndexPosition[      8160,        264]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CCDPhotometry`Conversions`", "Subsection",
  CellTags->"Conversions"],

Cell["\<\
This package contains functions for determining parameters necessary for the \
calculation of the heliocentric Julian date.\
\>", "Text",
  CellTags->"Conversions"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["EarthCoordinates",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox[\({h, \ m, \ s}\),
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[\({d, \ min, \ sec}\),
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              StyleBox["x",
                FontSlant->"Italic"],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`y\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`z\)]],
              
              " coordinates of the earth in a heliocentric coordinate \
system."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["SourceCoordinates",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox[\({h, \ m, \ s}\),
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[\({d, \ min, \ sec}\),
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              Cell[BoxData[
                  \(TraditionalForm\`x\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`y\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`z\)]],
              
              " coordinates of the source object in a heliocentric coordinate \
system."
            }], "Text"]}
          }], TextForm]], "DefinitionBox",
  CellTags->"Conversions"],

Cell["\<\
Converting geocentric coordinates into heliocentric coordinates \
\>", "Caption",
  CellTags->"Conversions"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["HeliocentricRA",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["modjuldate",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell["\<\
The right ascension of the earth in a heliocentric coordinate system, given \
the modified Julian date.\
\>", "Text"]},
          {
            RowBox[{
              StyleBox["HeliocentricDEC",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["modjuldate",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell["\<\
The declination of the earth in a heliocentric coordinate system, given the \
modified Julian date.\
\>", "Text"]}
          }], TextForm]], "DefinitionBox",
  CellTags->"Conversions"],

Cell["Calculating the heliocentric coordinates of the earth", "Caption",
  CellTags->"Conversions"],

Cell["This loads the package", "MathCaption",
  CellTags->"Conversions"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`Conversions`\>"]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Conversions"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`Dates`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Conversions"],

Cell["Here are the heliocentric x, y, z coordinates of the earth", \
"MathCaption",
  CellTags->"Conversions"],

Cell[BoxData[
    \(EarthCoordinates[{23, 23, 8.8}, {18, 24, 59. }]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Conversions"],

Cell["\<\
Here are the heliocentric x, y, z coordinates of a source object\
\>", "MathCaption",
  CellTags->"Conversions"],

Cell[BoxData[
    \(SourceCoordinates[{23, 23, 8.8}, {18, 28, 59.0}]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Conversions"],

Cell["Here is the right ascension of the earth in hours.", "MathCaption",
  CellTags->"Conversions"],

Cell[BoxData[
    \(HeliocentricRA[ModifiedJulianDate[Date[]]]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Conversions"],

Cell["Here is the declination of the earth in degrees.", "MathCaption",
  CellTags->"Conversions"],

Cell[BoxData[
    \(HeliocentricDEC[ModifiedJulianDate[Date[]]]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Conversions"]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{815, 651},
WindowMargins->{{25, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Conversions"->{
    Cell[1776, 53, 75, 1, 39, "Subsection",
      CellTags->"Conversions"],
    Cell[1854, 56, 174, 4, 25, "Text",
      CellTags->"Conversions"],
    Cell[2031, 62, 1755, 57, 70, "DefinitionBox",
      CellTags->"Conversions"],
    Cell[3789, 121, 118, 3, 17, "Caption",
      CellTags->"Conversions"],
    Cell[3910, 126, 889, 29, 104, "DefinitionBox",
      CellTags->"Conversions"],
    Cell[4802, 157, 99, 1, 17, "Caption",
      CellTags->"Conversions"],
    Cell[4904, 160, 72, 1, 31, "MathCaption",
      CellTags->"Conversions"],
    Cell[4979, 163, 123, 3, 29, "Input",
      CellTags->"Conversions"],
    Cell[5105, 168, 117, 3, 29, "Input",
      CellTags->"Conversions"],
    Cell[5225, 173, 110, 2, 31, "MathCaption",
      CellTags->"Conversions"],
    Cell[5338, 177, 131, 3, 29, "Input",
      CellTags->"Conversions"],
    Cell[5472, 182, 122, 3, 31, "MathCaption",
      CellTags->"Conversions"],
    Cell[5597, 187, 132, 3, 29, "Input",
      CellTags->"Conversions"],
    Cell[5732, 192, 100, 1, 31, "MathCaption",
      CellTags->"Conversions"],
    Cell[5835, 195, 126, 3, 29, "Input",
      CellTags->"Conversions"],
    Cell[5964, 200, 98, 1, 31, "MathCaption",
      CellTags->"Conversions"],
    Cell[6065, 203, 127, 3, 29, "Input",
      CellTags->"Conversions"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Conversions", 6842, 225}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 75, 1, 39, "Subsection",
  CellTags->"Conversions"],
Cell[1854, 56, 174, 4, 25, "Text",
  CellTags->"Conversions"],
Cell[2031, 62, 1755, 57, 70, "DefinitionBox",
  CellTags->"Conversions"],
Cell[3789, 121, 118, 3, 17, "Caption",
  CellTags->"Conversions"],
Cell[3910, 126, 889, 29, 104, "DefinitionBox",
  CellTags->"Conversions"],
Cell[4802, 157, 99, 1, 17, "Caption",
  CellTags->"Conversions"],
Cell[4904, 160, 72, 1, 31, "MathCaption",
  CellTags->"Conversions"],
Cell[4979, 163, 123, 3, 29, "Input",
  CellTags->"Conversions"],
Cell[5105, 168, 117, 3, 29, "Input",
  CellTags->"Conversions"],
Cell[5225, 173, 110, 2, 31, "MathCaption",
  CellTags->"Conversions"],
Cell[5338, 177, 131, 3, 29, "Input",
  CellTags->"Conversions"],
Cell[5472, 182, 122, 3, 31, "MathCaption",
  CellTags->"Conversions"],
Cell[5597, 187, 132, 3, 29, "Input",
  CellTags->"Conversions"],
Cell[5732, 192, 100, 1, 31, "MathCaption",
  CellTags->"Conversions"],
Cell[5835, 195, 126, 3, 29, "Input",
  CellTags->"Conversions"],
Cell[5964, 200, 98, 1, 31, "MathCaption",
  CellTags->"Conversions"],
Cell[6065, 203, 127, 3, 29, "Input",
  CellTags->"Conversions"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

