(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10550,        341]*)
(*NotebookOutlinePosition[     12389,        400]*)
(*  CellTagsIndexPosition[     12318,        394]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CCDPhotometry`Dates`", "Subsection",
  CellTags->"Dates"],

Cell["\<\
This package contains functions for calculating dates from various Julian \
based calendar systems.\
\>", "Text",
  CellTags->"Dates"],

Cell[BoxData[GridBox[{
        {
          RowBox[{"JulianDate", 
            StyleBox["[",
              "MR"], 
            StyleBox["date",
              "TI"], 
            StyleBox["]",
              "MR"]}], 
          RowBox[{
            StyleBox["Returns",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["the",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["Julian",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["date",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["for",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["the",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["specified",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["Gregorian",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            RowBox[{
              StyleBox["date",
                FontFamily->"Times New Roman",
                FontSlant->"Italic"], 
              StyleBox[".",
                FontFamily->"Times New Roman"]}]}]},
        {
          RowBox[{
            StyleBox["ModifiedJulianDate",
              "MR"], 
            StyleBox["[",
              "MR"], 
            StyleBox["date",
              "TI"], 
            StyleBox["]",
              "MR"]}], 
          StyleBox[
            RowBox[{
            "Returns", " ", "the", " ", "modified", " ", "Julian", " ", 
              "date", " ", "for", " ", "the", " ", "specified", " ", 
              "Gregorian", " ", 
              RowBox[{
                StyleBox["date",
                  FontSlant->"Italic"], "."}]}],
            FontFamily->"Times New Roman"]},
        {
          RowBox[{
            StyleBox["HeliocentricCorrectionTime",
              "MR"], 
            StyleBox["[",
              "MR"], 
            RowBox[{
              StyleBox["date",
                "TI"], 
              StyleBox[",",
                "MR"], 
              StyleBox[" ",
                "MR"], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["hour",
                    "TI"], ",", " ", 
                  StyleBox["min",
                    "TI"], ",", " ", 
                  StyleBox["sec",
                    "TI"]}], "}"}], 
              StyleBox[",",
                "MR"], 
              StyleBox[" ",
                "MR"], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["d",
                    "TI"], ",", " ", 
                  StyleBox["m",
                    "TI"], ",", " ", 
                  StyleBox["s",
                    "TI"], "}"}]}]}], 
            StyleBox["]",
              "MR"]}], 
          RowBox[{
            StyleBox[
              RowBox[{
              "Returns", " ", "the", " ", "heliocentric", " ", "correction", 
                " ", "time", " ", "in", " ", "seconds", " ", "for", " ", 
                "the", " ", "specified", " ", 
                StyleBox["date",
                  FontSlant->"Italic"]}],
              FontFamily->"Times New Roman"], 
            StyleBox[",",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox[\(right\ ascension\),
              FontFamily->"Times New Roman",
              FontSlant->"Italic"], 
            StyleBox[",",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox[
              RowBox[{"and", " ", 
                StyleBox[\(\(declination\)\(.\)\),
                  FontSlant->"Italic"]}],
              FontFamily->"Times New Roman"]}]},
        {
          RowBox[{
            StyleBox["HeliocentricJulianDate",
              "MR"], 
            StyleBox["[",
              "MR"], 
            RowBox[{
              StyleBox["date",
                "TI"], 
              StyleBox[",",
                "MR"], 
              StyleBox[" ",
                "MR"], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["hour",
                    "TI"], ",", " ", 
                  StyleBox["min",
                    "TI"], ",", " ", 
                  StyleBox["sec",
                    "TI"]}], "}"}], 
              StyleBox[",",
                "MR"], 
              StyleBox[" ",
                "MR"], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["d",
                    "TI"], ",", " ", 
                  StyleBox["m",
                    "TI"], ",", " ", 
                  StyleBox["s",
                    "TI"], "}"}]}]}], 
            StyleBox["]",
              "MR"]}], 
          StyleBox[\(Returns\ the\ heliocentric\ Julian\ date\),
            FontFamily->"Times New Roman"]}
        }]], "DefinitionBox",
  CellTags->"Dates"],

Cell["Calculating Julian calendar dates", "Caption",
  CellTags->"Dates"],

Cell["This loads the package", "MathCaption",
  CellTags->"Dates"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`Dates`\>"]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Dates"],

Cell["Here is the Julian date for the current date.", "MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AccountingForm[JulianDate[Date[]], 16]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Dates"],

Cell[BoxData[
    TagBox[
      InterpretationBox["\<\"2452747.127926552\"\>",
        2452747.1279265522,
        AutoDelete->True],
      (AccountingForm[ #, 16]&)]], "Output",
  CellLabel->"Out[2]//AccountingForm="]
}, Open  ]],

Cell["\<\
The modified Julian date corresponds to 2400000.5 days after day 0 of the \
Julian calendar. It therefore gives the number of days since midnight on \
November 17, 1858. The modified Julian date is still in common usage in \
tabulations by the U. S. Naval Observatory. \
\>", "Text",
  CellTags->"Dates"],

Cell["Here is the modified Julian date for the current date.", "MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AccountingForm[ModifiedJulianDate[Date[]], 16]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Dates"],

Cell[BoxData[
    TagBox[
      InterpretationBox["\<\"52746.62794735003\"\>",
        52746.627947350033,
        AutoDelete->True],
      (AccountingForm[ #, 16]&)]], "Output",
  CellLabel->"Out[3]//AccountingForm="]
}, Open  ]],

Cell[TextData[{
  "The heliocentric Julian date is the Julian date for a specified set of sky \
coordinates in a heliocentric coordinate system.  This is necessary to \
compensate for the difference in light travel time between the earth and the \
sun.  The earth's position in its orbit changes with time and can therefore \
result in at most an ",
  Cell[BoxData[
      \(TraditionalForm\`\(8\^m\) 13\^s\)]],
  "variation in timing observations.  To compensate for this, the sun is \
chosen as the origin of the coordinate system since its distance from the \
source object is more stable."
}], "Text",
  CellTags->"Dates"],

Cell["\<\
Here is the heliocentric correction time for the current date in days.\
\>", "MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HeliocentricCorrectionTime[
      Date[], {23, 23, 8.8}, {18, 28, 59.0}]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Dates"],

Cell[BoxData[
    \(\(-0.0014933045367392405`\)\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["Here is the heliocentric Julian date for the current date.", \
"MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AccountingForm[
      HeliocentricJulianDate[Date[], {23, 23, 8.8}, {18, 28, 59.0}], 
      16]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Dates"],

Cell[BoxData[
    TagBox[
      InterpretationBox["\<\"2452747.12649148\"\>",
        2452747.12649148,
        AutoDelete->True],
      (AccountingForm[ #, 16]&)]], "Output",
  CellLabel->"Out[5]//AccountingForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{815, 651},
WindowMargins->{{20, Automatic}, {Automatic, -6}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Dates"->{
    Cell[1776, 53, 63, 1, 39, "Subsection",
      CellTags->"Dates"],
    Cell[1842, 56, 144, 4, 25, "Text",
      CellTags->"Dates"],
    Cell[1989, 62, 5457, 165, 146, "DefinitionBox",
      CellTags->"Dates"],
    Cell[7449, 229, 73, 1, 17, "Caption",
      CellTags->"Dates"],
    Cell[7525, 232, 66, 1, 31, "MathCaption",
      CellTags->"Dates"],
    Cell[7594, 235, 111, 3, 29, "Input",
      CellTags->"Dates"],
    Cell[7708, 240, 89, 1, 31, "MathCaption",
      CellTags->"Dates"],
    Cell[7822, 245, 116, 3, 29, "Input",
      CellTags->"Dates"],
    Cell[8174, 259, 314, 6, 42, "Text",
      CellTags->"Dates"],
    Cell[8491, 267, 98, 1, 31, "MathCaption",
      CellTags->"Dates"],
    Cell[8614, 272, 124, 3, 29, "Input",
      CellTags->"Dates"],
    Cell[8974, 286, 625, 12, 76, "Text",
      CellTags->"Dates"],
    Cell[9602, 300, 122, 3, 31, "MathCaption",
      CellTags->"Dates"],
    Cell[9749, 307, 150, 4, 29, "Input",
      CellTags->"Dates"],
    Cell[10002, 318, 104, 2, 31, "MathCaption",
      CellTags->"Dates"],
    Cell[10131, 324, 173, 5, 29, "Input",
      CellTags->"Dates"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Dates", 11179, 357}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 63, 1, 39, "Subsection",
  CellTags->"Dates"],
Cell[1842, 56, 144, 4, 25, "Text",
  CellTags->"Dates"],
Cell[1989, 62, 5457, 165, 146, "DefinitionBox",
  CellTags->"Dates"],
Cell[7449, 229, 73, 1, 17, "Caption",
  CellTags->"Dates"],
Cell[7525, 232, 66, 1, 31, "MathCaption",
  CellTags->"Dates"],
Cell[7594, 235, 111, 3, 29, "Input",
  CellTags->"Dates"],
Cell[7708, 240, 89, 1, 31, "MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{
Cell[7822, 245, 116, 3, 29, "Input",
  CellTags->"Dates"],
Cell[7941, 250, 218, 6, 37, "Output"]
}, Open  ]],
Cell[8174, 259, 314, 6, 42, "Text",
  CellTags->"Dates"],
Cell[8491, 267, 98, 1, 31, "MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{
Cell[8614, 272, 124, 3, 29, "Input",
  CellTags->"Dates"],
Cell[8741, 277, 218, 6, 37, "Output"]
}, Open  ]],
Cell[8974, 286, 625, 12, 76, "Text",
  CellTags->"Dates"],
Cell[9602, 300, 122, 3, 31, "MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{
Cell[9749, 307, 150, 4, 29, "Input",
  CellTags->"Dates"],
Cell[9902, 313, 85, 2, 23, "Output"]
}, Open  ]],
Cell[10002, 318, 104, 2, 31, "MathCaption",
  CellTags->"Dates"],

Cell[CellGroupData[{
Cell[10131, 324, 173, 5, 29, "Input",
  CellTags->"Dates"],
Cell[10307, 331, 215, 6, 37, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

