(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9987,        329]*)
(*NotebookOutlinePosition[     12516,        406]*)
(*  CellTagsIndexPosition[     12443,        400]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CCDPhotometry`Headers`", "Subsection",
  CellTags->"Headers"],

Cell["\<\
This package contains functions for extracting information from FITS image \
headers.\
\>", "Text",
  CellTags->"Headers"],

Cell[BoxData[{
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Header",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["imobj",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell["\<\
Returns the full contents of the header data from the specified FITS image \
object.\
\>", "Text"]},
          {
            RowBox[{
              StyleBox["Header",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["imobj",
                "TI"], ",", 
              StyleBox["\"\<field\>\"",
                "TI",
                ShowStringCharacters->True], 
              StyleBox["]",
                "MR"]}], Cell["\<\
Returns the string value of the specified field in the specified FITS object.\
\
\>", "Text"]},
          {
            RowBox[{
              StyleBox["ImageTime",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["imobj",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              
              "Returns the starting Universal time of the image acquisition \
in the form {",
              Cell[BoxData[
                  \(TraditionalForm\`year\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`month\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`day\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`hour\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`min\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`sec\)]],
              "}."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["ImageRA",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["imobj",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              
              "Returns the right ascension value contained in the header of \
the specified FITS object. Results of the form {",
              Cell[BoxData[
                  \(TraditionalForm\`hours\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`minutes\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`seconds\)]],
              "}."
            }], "Text"]}
          }], TextForm], "\n", 
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ImageDEC",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["imobj",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              
              "Returns the declination value contained in the header of the \
specified FITS object.Results of the form {",
              Cell[BoxData[
                  \(TraditionalForm\`degrees\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`minutes\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`seconds\)]],
              "}."
            }], "Text"]}
          }], TextForm]}], "DefinitionBox",
  CellTags->"Headers"],

Cell["Extracting header information", "Caption",
  CellTags->"Headers"],

Cell["This loads the package", "MathCaption",
  CellTags->"Headers"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`Headers`\>"]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Headers"],

Cell["A FITS image is needed", "MathCaption",
  CellTags->"Headers"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`ImageLoad`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Headers"],

Cell[BoxData[
    \(data = 
      ImageLoad[
        ToFileName["\<CCDPhotometry\>", "\<11080154.fit\>"]]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Headers"],

Cell["\<\
Here are the entire contents of the above specified FITS image.\
\>", "MathCaption",
  CellTags->"Headers"],

Cell[BoxData[
    \(Header[data]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Headers"],

Cell["\<\
All of the contents of a FITS header, field names and values, are stored as \
strings.\
\>", "Text",
  CellTags->"Headers"],

Cell["Here is the value of a specific filed in the above header.", \
"MathCaption",
  CellTags->"Headers"],

Cell[BoxData[
    \(HeaderField[data, "\<FILTER\>"]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Headers"],

Cell["\<\
A few functions are available that attempt to process the string contents and \
return numerical results.\
\>", "Text",
  CellTags->"Headers"],

Cell[BoxData[
    FormBox[GridBox[{
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"option name\"\>",
                      "TI"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"default value\"\>",
                      "TI"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`\[Null]\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"DateTimeParsingFunctions\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"{dateparser, timeparser}\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"\<a list containing pure functions for \
parsing the date and time fields, respectively.\>"\)]]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DefinitionBox3Col",
  GridBoxOptions->{RowSpacings->0.4,
  RowLines->{True, False}},
  CellTags->"Headers"],

Cell["Options for parsing dates and times", "Caption",
  CellTags->"Headers"],

Cell["Here is start time of the image acquisition.", "MathCaption",
  CellTags->"Headers"],

Cell[BoxData[
    \(ImageTime[data]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Headers"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["\<\"option name\"\>",
              "TI"], 
            StyleBox["\<\"default values\"\>",
              "TI"], " "},
          {Cell[BoxData[
                FormBox[
                  StyleBox["ParsingFunction",
                    "MR"], TraditionalForm]]], Cell[BoxData[
                FormBox[
                  StyleBox["RAParsingFunction",
                    "MR"], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"\<a function that parses the RA field of \
the FITS image object.\>"\)]]},
          {Cell[BoxData[
                FormBox[
                  StyleBox[" ",
                    "MR"], TraditionalForm]]], Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"DECParsingFunction\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"\<a function that parses the DEC field of \
the FITS image object.\>"\)]]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DefinitionBox3Col",
  GridBoxOptions->{RowSpacings->0.4,
  RowLines->{True, False}},
  CellTags->"Headers"],

Cell["Option for parsing right ascension and declination", "Caption",
  CellTags->"Headers"],

Cell["\<\
Here is right ascension parameter of the telescope for the above image.\
\>", "MathCaption",
  CellTags->"Headers"],

Cell[BoxData[
    \(ImageRA[data]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"Headers"],

Cell["\<\
Here is declination parameter of the telescope for the above image.\
\>", "MathCaption",
  CellTags->"Headers"],

Cell[BoxData[
    \(ImageDEC[data]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"Headers"]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{977, 651},
WindowMargins->{{Automatic, 3}, {Automatic, 5}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Headers"->{
    Cell[1776, 53, 67, 1, 39, "Subsection",
      CellTags->"Headers"],
    Cell[1846, 56, 132, 4, 25, "Text",
      CellTags->"Headers"],
    Cell[1981, 62, 3415, 112, 192, "DefinitionBox",
      CellTags->"Headers"],
    Cell[5399, 176, 71, 1, 17, "Caption",
      CellTags->"Headers"],
    Cell[5473, 179, 68, 1, 31, "MathCaption",
      CellTags->"Headers"],
    Cell[5544, 182, 115, 3, 29, "Input",
      CellTags->"Headers"],
    Cell[5662, 187, 68, 1, 31, "MathCaption",
      CellTags->"Headers"],
    Cell[5733, 190, 117, 3, 29, "Input",
      CellTags->"Headers"],
    Cell[5853, 195, 165, 5, 29, "Input",
      CellTags->"Headers"],
    Cell[6021, 202, 117, 3, 31, "MathCaption",
      CellTags->"Headers"],
    Cell[6141, 207, 92, 3, 29, "Input",
      CellTags->"Headers"],
    Cell[6236, 212, 133, 4, 25, "Text",
      CellTags->"Headers"],
    Cell[6372, 218, 106, 2, 31, "MathCaption",
      CellTags->"Headers"],
    Cell[6481, 222, 111, 3, 29, "Input",
      CellTags->"Headers"],
    Cell[6595, 227, 152, 4, 25, "Text",
      CellTags->"Headers"],
    Cell[6750, 233, 1199, 27, 62, "DefinitionBox3Col",
      CellTags->"Headers"],
    Cell[7952, 262, 77, 1, 17, "Caption",
      CellTags->"Headers"],
    Cell[8032, 265, 90, 1, 31, "MathCaption",
      CellTags->"Headers"],
    Cell[8125, 268, 95, 3, 29, "Input",
      CellTags->"Headers"],
    Cell[8223, 273, 1208, 30, 76, "DefinitionBox3Col",
      CellTags->"Headers"],
    Cell[9434, 305, 92, 1, 17, "Caption",
      CellTags->"Headers"],
    Cell[9529, 308, 125, 3, 45, "MathCaption",
      CellTags->"Headers"],
    Cell[9657, 313, 93, 3, 29, "Input",
      CellTags->"Headers"],
    Cell[9753, 318, 121, 3, 45, "MathCaption",
      CellTags->"Headers"],
    Cell[9877, 323, 94, 3, 29, "Input",
      CellTags->"Headers"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Headers", 10616, 345}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 1, 39, "Subsection",
  CellTags->"Headers"],
Cell[1846, 56, 132, 4, 25, "Text",
  CellTags->"Headers"],
Cell[1981, 62, 3415, 112, 192, "DefinitionBox",
  CellTags->"Headers"],
Cell[5399, 176, 71, 1, 17, "Caption",
  CellTags->"Headers"],
Cell[5473, 179, 68, 1, 31, "MathCaption",
  CellTags->"Headers"],
Cell[5544, 182, 115, 3, 29, "Input",
  CellTags->"Headers"],
Cell[5662, 187, 68, 1, 31, "MathCaption",
  CellTags->"Headers"],
Cell[5733, 190, 117, 3, 29, "Input",
  CellTags->"Headers"],
Cell[5853, 195, 165, 5, 29, "Input",
  CellTags->"Headers"],
Cell[6021, 202, 117, 3, 31, "MathCaption",
  CellTags->"Headers"],
Cell[6141, 207, 92, 3, 29, "Input",
  CellTags->"Headers"],
Cell[6236, 212, 133, 4, 25, "Text",
  CellTags->"Headers"],
Cell[6372, 218, 106, 2, 31, "MathCaption",
  CellTags->"Headers"],
Cell[6481, 222, 111, 3, 29, "Input",
  CellTags->"Headers"],
Cell[6595, 227, 152, 4, 25, "Text",
  CellTags->"Headers"],
Cell[6750, 233, 1199, 27, 62, "DefinitionBox3Col",
  CellTags->"Headers"],
Cell[7952, 262, 77, 1, 17, "Caption",
  CellTags->"Headers"],
Cell[8032, 265, 90, 1, 31, "MathCaption",
  CellTags->"Headers"],
Cell[8125, 268, 95, 3, 29, "Input",
  CellTags->"Headers"],
Cell[8223, 273, 1208, 30, 76, "DefinitionBox3Col",
  CellTags->"Headers"],
Cell[9434, 305, 92, 1, 17, "Caption",
  CellTags->"Headers"],
Cell[9529, 308, 125, 3, 45, "MathCaption",
  CellTags->"Headers"],
Cell[9657, 313, 93, 3, 29, "Input",
  CellTags->"Headers"],
Cell[9753, 318, 121, 3, 45, "MathCaption",
  CellTags->"Headers"],
Cell[9877, 323, 94, 3, 29, "Input",
  CellTags->"Headers"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

