(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7052,        236]*)
(*NotebookOutlinePosition[      9128,        299]*)
(*  CellTagsIndexPosition[      9053,        293]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CCDPhotometry`Photometry`", "Subsection",
  CellTags->"Photometry"],

Cell["\<\
This package contains functions useful in photometry calculations.\
\>", "Text",
  CellTags->"Photometry"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["IsolateRegion",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["imobj",
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[" ",
                  "MR"], 
                StyleBox[\({i, \ j}\),
                  "TI"], 
                StyleBox[\(\(,\)\(\ \)\),
                  "MR"], 
                StyleBox["r",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              
              "Returns a submatrix of the supplied FITS image object that is \
centered at {",
              Cell[BoxData[
                  \(TraditionalForm\`i\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`j\)]],
              "} and has width and height, ",
              Cell[BoxData[
                  \(TraditionalForm\`r\)]],
              "."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["Photometry",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["imobj",
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[" ",
                  "MR"], 
                StyleBox[\({x, \ y}\),
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[" ",
                  "MR"], 
                StyleBox["rad",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              
              "Sums up all of the pixel values in the specified FITS data \
object that are centered at {",
              Cell[BoxData[
                  \(TraditionalForm\`x\)]],
              ", ",
              Cell[BoxData[
                  \(TraditionalForm\`y\)]],
              "} and that lie within a circular aperture with radius, ",
              Cell[BoxData[
                  \(TraditionalForm\`rad\)]],
              "."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["Phase",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["imobj",
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[" ",
                  "MR"], 
                StyleBox["knownmin",
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[" ",
                  "MR"], 
                StyleBox["orbper",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              
              "Returns the orbital phase of an object based on information in \
the header of the FITS image object. The HJD of a known minimum, ",
              Cell[BoxData[
                  \(TraditionalForm\`knownmin\)]],
              ", and the orbital period in days, ",
              Cell[BoxData[
                  \(TraditionalForm\`orbper\)]],
              ", are also required."
            }], "Text"]}
          }], TextForm]], "DefinitionBox",
  CellTags->"Photometry"],

Cell["Photometry calculations", "Caption",
  CellTags->"Photometry"],

Cell["This loads the package", "MathCaption",
  CellTags->"Photometry"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`Photometry`\>"]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Photometry"],

Cell["This loads the packages for image loading and display.", "MathCaption",
  CellTags->"Photometry"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`ImageLoad`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Photometry"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`DisplayImage`\>"]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Photometry"],

Cell["This loads the data and displays it.", "MathCaption",
  CellTags->"Photometry"],

Cell[BoxData[
    \(data = 
      ImageLoad[
        ToFileName["\<CCDPhotometry\>", "\<11080154.fit\>"]]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Photometry"],

Cell[BoxData[
    \(\(DisplayImage[data, PlotRange \[Rule] {4, 75}];\)\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Photometry"],

Cell["Here is an isolated subset of the above data.", "MathCaption",
  CellTags->"Photometry"],

Cell[BoxData[
    \(IsolateRegion[data, {100, 100}, 5]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Photometry"],

Cell["Pixel sums can be performed as follows", "MathCaption",
  CellTags->"Photometry"],

Cell[BoxData[
    \(Photometry[data, {253, 277}, 10]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"Photometry"],

Cell["\<\
For sources with known orbital periods, the orbital phase of the data can be \
calculated. \
\>", "MathCaption",
  CellTags->"Photometry"],

Cell[BoxData[
    \(Phase[data, 2445615.42244, 0.158206164]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"Photometry"]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{815, 651},
WindowMargins->{{24, Automatic}, {Automatic, -3}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Photometry"->{
    Cell[1776, 53, 73, 1, 39, "Subsection",
      CellTags->"Photometry"],
    Cell[1852, 56, 116, 3, 25, "Text",
      CellTags->"Photometry"],
    Cell[1971, 61, 3345, 106, 164, "DefinitionBox",
      CellTags->"Photometry"],
    Cell[5319, 169, 68, 1, 17, "Caption",
      CellTags->"Photometry"],
    Cell[5390, 172, 71, 1, 31, "MathCaption",
      CellTags->"Photometry"],
    Cell[5464, 175, 121, 3, 29, "Input",
      CellTags->"Photometry"],
    Cell[5588, 180, 103, 1, 31, "MathCaption",
      CellTags->"Photometry"],
    Cell[5694, 183, 120, 3, 29, "Input",
      CellTags->"Photometry"],
    Cell[5817, 188, 123, 3, 29, "Input",
      CellTags->"Photometry"],
    Cell[5943, 193, 85, 1, 31, "MathCaption",
      CellTags->"Photometry"],
    Cell[6031, 196, 168, 5, 29, "Input",
      CellTags->"Photometry"],
    Cell[6202, 203, 133, 3, 29, "Input",
      CellTags->"Photometry"],
    Cell[6338, 208, 94, 1, 31, "MathCaption",
      CellTags->"Photometry"],
    Cell[6435, 211, 117, 3, 29, "Input",
      CellTags->"Photometry"],
    Cell[6555, 216, 87, 1, 31, "MathCaption",
      CellTags->"Photometry"],
    Cell[6645, 219, 115, 3, 29, "Input",
      CellTags->"Photometry"],
    Cell[6763, 224, 148, 4, 31, "MathCaption",
      CellTags->"Photometry"],
    Cell[6914, 230, 122, 3, 29, "Input",
      CellTags->"Photometry"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Photometry", 7686, 252}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 73, 1, 39, "Subsection",
  CellTags->"Photometry"],
Cell[1852, 56, 116, 3, 25, "Text",
  CellTags->"Photometry"],
Cell[1971, 61, 3345, 106, 164, "DefinitionBox",
  CellTags->"Photometry"],
Cell[5319, 169, 68, 1, 17, "Caption",
  CellTags->"Photometry"],
Cell[5390, 172, 71, 1, 31, "MathCaption",
  CellTags->"Photometry"],
Cell[5464, 175, 121, 3, 29, "Input",
  CellTags->"Photometry"],
Cell[5588, 180, 103, 1, 31, "MathCaption",
  CellTags->"Photometry"],
Cell[5694, 183, 120, 3, 29, "Input",
  CellTags->"Photometry"],
Cell[5817, 188, 123, 3, 29, "Input",
  CellTags->"Photometry"],
Cell[5943, 193, 85, 1, 31, "MathCaption",
  CellTags->"Photometry"],
Cell[6031, 196, 168, 5, 29, "Input",
  CellTags->"Photometry"],
Cell[6202, 203, 133, 3, 29, "Input",
  CellTags->"Photometry"],
Cell[6338, 208, 94, 1, 31, "MathCaption",
  CellTags->"Photometry"],
Cell[6435, 211, 117, 3, 29, "Input",
  CellTags->"Photometry"],
Cell[6555, 216, 87, 1, 31, "MathCaption",
  CellTags->"Photometry"],
Cell[6645, 219, 115, 3, 29, "Input",
  CellTags->"Photometry"],
Cell[6763, 224, 148, 4, 31, "MathCaption",
  CellTags->"Photometry"],
Cell[6914, 230, 122, 3, 29, "Input",
  CellTags->"Photometry"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

