(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12754,        423]*)
(*NotebookOutlinePosition[     15569,        506]*)
(*  CellTagsIndexPosition[     15494,        500]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CCDPhotometry`Reduction`", "Subsection",
  CellTags->"Reduction"],

Cell["\<\
This package contains functions for reducing CCD FITS data in preparation for \
data extraction.\
\>", "Text",
  CellTags->"Reduction"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["AverageFrame",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["files",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell["\<\
Returns an average of FITS objects from a list of specified FITS objects.\
\>", "Text"]},
          {
            RowBox[{
              StyleBox["SubtractFrame",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(file1, \ file2\),
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              "Subtracts the data of ",
              StyleBox["file2",
                FontSlant->"Italic"],
              " from ",
              StyleBox["file1",
                FontSlant->"Italic"],
              " and returns a new FITS object with the header of ",
              StyleBox["file1",
                FontSlant->"Italic"],
              "."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["NormalizeFlat",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["file",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              "Assumes that ",
              StyleBox["file",
                FontSlant->"Italic"],
              " is a flat-field image and normalizes the field."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["RemoveOverscan",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["file",
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[" ",
                  "MR"], 
                RowBox[{
                  StyleBox["{",
                    "MR"], 
                  RowBox[{
                    StyleBox["lb",
                      "TI"], 
                    StyleBox[",",
                      "MR"], 
                    StyleBox[" ",
                      "MR"], 
                    StyleBox["ub",
                      "TI"]}], 
                  StyleBox["}",
                    "MR"]}]}], 
              StyleBox["]",
                "MR"]}], 
            FormBox[Cell[TextData[{
                "removes the overscan region specified from lowerbound,",
                StyleBox[" lb",
                  FontSlant->"Italic"],
                ", to upper bound, ",
                StyleBox["ub",
                  FontSlant->"Italic"],
                ", from the FITS data, ",
                StyleBox["file",
                  FontSlant->"Italic"],
                "."
              }], "Text"],
              "TextForm"]},
          {
            RowBox[{
              StyleBox["FlatField",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(imagefile, \ biasfile, \ normflatfile\),
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{" ", Cell[TextData[{
                "Assumes that",
                StyleBox[" normflatfile",
                  FontSlant->"Italic"],
                
                " is a normalized flat-field frame and divides the bias \
subtracted ",
                StyleBox["imagefile",
                  FontSlant->"Italic"],
                " by the ",
                StyleBox["normflatfile",
                  FontSlant->"Italic"],
                "."
              }], "Text"]}]}
          }], TextForm]], "DefinitionBox",
  CellTags->"Reduction"],

Cell["Image Reduction for Files", "Caption",
  CellTags->"Reduction"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["AverageFrame",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["{",
                  "MR"], 
                StyleBox[\(imgobj1,  ... , imgobjn\),
                  "TI"], 
                StyleBox["}",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], Cell["\<\
Returns an average of FITS objects from a list of specified FITS objects.\
\>", "Text"]},
          {
            RowBox[{
              StyleBox["SubtractFrame",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(imgobj1, \ imgobj2\),
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              "Subtracts the data of ",
              StyleBox["imgobj2",
                FontSlant->"Italic"],
              " from ",
              StyleBox["imobj1",
                FontSlant->"Italic"],
              " and returns a new FITS object with the header of ",
              StyleBox["imgobj1",
                FontSlant->"Italic"],
              "."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["NormalizeFlat",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["imgobj",
                "TI"], 
              StyleBox["]",
                "MR"]}], Cell[TextData[{
              "Assumes that ",
              StyleBox["imgobj",
                FontSlant->"Italic"],
              " is a flat-field image and normalizes the field."
            }], "Text"]},
          {
            RowBox[{
              StyleBox["RemoveOverscan",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["imgobj",
                  "TI"], 
                StyleBox[",",
                  "MR"], 
                StyleBox[" ",
                  "MR"], 
                RowBox[{
                  StyleBox["{",
                    "MR"], 
                  RowBox[{
                    StyleBox["lb",
                      "TI"], 
                    StyleBox[",",
                      "MR"], 
                    StyleBox[" ",
                      "MR"], 
                    StyleBox["ub",
                      "TI"]}], 
                  StyleBox["}",
                    "MR"]}]}], 
              StyleBox["]",
                "MR"]}], 
            FormBox[Cell[TextData[{
                "removes the overscan region specified from lowerbound,",
                StyleBox[" lb",
                  FontSlant->"Italic"],
                ", to upper bound, ",
                StyleBox["ub",
                  FontSlant->"Italic"],
                ", from the FITS data, ",
                StyleBox["imgobj",
                  FontSlant->"Italic"],
                "."
              }], "Text"],
              "TextForm"]},
          {
            RowBox[{
              StyleBox["FlatField",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(imageobj, \ biasobj, \ normflatobj\),
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{" ", Cell[TextData[{
                "Assumes that",
                StyleBox[" normflatfobj",
                  FontSlant->"Italic"],
                
                " is a normalized flat-field frame and divides the bias \
subtracted ",
                StyleBox["imageobj",
                  FontSlant->"Italic"],
                " by the ",
                StyleBox["normflatobj",
                  FontSlant->"Italic"],
                "."
              }], "Text"]}]}
          }], TextForm]], "DefinitionBox",
  CellTags->"Reduction"],

Cell["Image Reduction for FITS Objects", "Caption",
  CellTags->"Reduction"],

Cell["This loads the package.", "MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`Reduction`\>"]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Reduction"],

Cell["This loads packages for reading images and displaying them.", \
"MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`ImageLoad`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Reduction"],

Cell[BoxData[
    \(Needs["\<CCDPhotometry`DisplayImage`\>"]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Reduction"],

Cell["Now we load the image, bias, and flat-field frames", "MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(rawimg = 
      ImageLoad[
        ToFileName["\<CCDPhotometry\>", "\<May08_0132.fit\>"]]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Reduction"],

Cell[BoxData[
    \(img = RemoveOverscan[rawimg, {1, 512}]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Reduction"],

Cell[BoxData[
    \(bias = 
      ImageLoad[
        ToFileName["\<CCDPhotometry\>", "\<avgbias.fit\>"]]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Reduction"],

Cell[BoxData[
    \(rawvflat = 
      ImageLoad[
        ToFileName["\<CCDPhotometry\>", "\<avgvflat.fit\>"]]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"Reduction"],

Cell["We can view them", "MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{DisplayImage[img, DisplayFunction \[Rule] Identity], 
            DisplayImage[bias, DisplayFunction \[Rule] Identity, 
              PlotRange \[Rule] {1052, 1058}], 
            DisplayImage[rawvflat, DisplayFunction \[Rule] Identity]}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 500];\)\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"Reduction"],

Cell["We can bias subtract the raw flat-field frame.", "MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(vflat = SubtractFrame[rawvflat, bias]\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"Reduction"],

Cell["This is how a normalized flat-field frame is created.", "MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(normvflat = NormalizeFlat[vflat]\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"Reduction"],

Cell["This is how the image frame is flat-fielded.", "MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(final = FlatField[img, bias, normvflat]\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"Reduction"],

Cell["We can view the reduced image, ready for data extraction.", \
"MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(\(DisplayImage[final];\)\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->"Reduction"],

Cell[TextData[{
  "By adjusting the ",
  StyleBox["PlotRange",
    FontFamily->"Courier"],
  ", we can change the contrast revealing internal details."
}], "MathCaption",
  CellTags->"Reduction"],

Cell[BoxData[
    \(\(DisplayImage[final, PlotRange \[Rule] {75, 2500}];\)\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"Reduction"]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{815, 651},
WindowMargins->{{87, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Reduction"->{
    Cell[1776, 53, 71, 1, 39, "Subsection",
      CellTags->"Reduction"],
    Cell[1850, 56, 145, 4, 25, "Text",
      CellTags->"Reduction"],
    Cell[1998, 62, 3695, 117, 182, "DefinitionBox",
      CellTags->"Reduction"],
    Cell[5696, 181, 69, 1, 17, "Caption",
      CellTags->"Reduction"],
    Cell[5768, 184, 3868, 122, 200, "DefinitionBox",
      CellTags->"Reduction"],
    Cell[9639, 308, 76, 1, 17, "Caption",
      CellTags->"Reduction"],
    Cell[9718, 311, 71, 1, 31, "MathCaption",
      CellTags->"Reduction"],
    Cell[9792, 314, 119, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[9914, 319, 109, 2, 31, "MathCaption",
      CellTags->"Reduction"],
    Cell[10026, 323, 119, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[10148, 328, 122, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[10273, 333, 98, 1, 31, "MathCaption",
      CellTags->"Reduction"],
    Cell[10374, 336, 171, 5, 29, "Input",
      CellTags->"Reduction"],
    Cell[10548, 343, 120, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[10671, 348, 166, 5, 29, "Input",
      CellTags->"Reduction"],
    Cell[10840, 355, 171, 5, 29, "Input",
      CellTags->"Reduction"],
    Cell[11014, 362, 64, 1, 45, "MathCaption",
      CellTags->"Reduction"],
    Cell[11081, 365, 438, 9, 89, "Input",
      CellTags->"Reduction"],
    Cell[11522, 376, 94, 1, 45, "MathCaption",
      CellTags->"Reduction"],
    Cell[11619, 379, 119, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[11741, 384, 101, 1, 45, "MathCaption",
      CellTags->"Reduction"],
    Cell[11845, 387, 115, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[11963, 392, 92, 1, 45, "MathCaption",
      CellTags->"Reduction"],
    Cell[12058, 395, 122, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[12183, 400, 107, 2, 45, "MathCaption",
      CellTags->"Reduction"],
    Cell[12293, 404, 107, 3, 29, "Input",
      CellTags->"Reduction"],
    Cell[12403, 409, 195, 6, 45, "MathCaption",
      CellTags->"Reduction"],
    Cell[12601, 417, 137, 3, 29, "Input",
      CellTags->"Reduction"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Reduction", 13386, 439}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 71, 1, 39, "Subsection",
  CellTags->"Reduction"],
Cell[1850, 56, 145, 4, 25, "Text",
  CellTags->"Reduction"],
Cell[1998, 62, 3695, 117, 182, "DefinitionBox",
  CellTags->"Reduction"],
Cell[5696, 181, 69, 1, 17, "Caption",
  CellTags->"Reduction"],
Cell[5768, 184, 3868, 122, 200, "DefinitionBox",
  CellTags->"Reduction"],
Cell[9639, 308, 76, 1, 17, "Caption",
  CellTags->"Reduction"],
Cell[9718, 311, 71, 1, 31, "MathCaption",
  CellTags->"Reduction"],
Cell[9792, 314, 119, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[9914, 319, 109, 2, 31, "MathCaption",
  CellTags->"Reduction"],
Cell[10026, 323, 119, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[10148, 328, 122, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[10273, 333, 98, 1, 31, "MathCaption",
  CellTags->"Reduction"],
Cell[10374, 336, 171, 5, 29, "Input",
  CellTags->"Reduction"],
Cell[10548, 343, 120, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[10671, 348, 166, 5, 29, "Input",
  CellTags->"Reduction"],
Cell[10840, 355, 171, 5, 29, "Input",
  CellTags->"Reduction"],
Cell[11014, 362, 64, 1, 45, "MathCaption",
  CellTags->"Reduction"],
Cell[11081, 365, 438, 9, 89, "Input",
  CellTags->"Reduction"],
Cell[11522, 376, 94, 1, 45, "MathCaption",
  CellTags->"Reduction"],
Cell[11619, 379, 119, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[11741, 384, 101, 1, 45, "MathCaption",
  CellTags->"Reduction"],
Cell[11845, 387, 115, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[11963, 392, 92, 1, 45, "MathCaption",
  CellTags->"Reduction"],
Cell[12058, 395, 122, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[12183, 400, 107, 2, 45, "MathCaption",
  CellTags->"Reduction"],
Cell[12293, 404, 107, 3, 29, "Input",
  CellTags->"Reduction"],
Cell[12403, 409, 195, 6, 45, "MathCaption",
  CellTags->"Reduction"],
Cell[12601, 417, 137, 3, 29, "Input",
  CellTags->"Reduction"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

